@@ -278,7 +278,7 @@ class WFReport(HTMLReport):
 
     def __init__(
             self, title, workflow, commit=None, revision=None,
-            require_keys=False, about=True, style='ont'):
+            require_keys=False, about=True, style='ont', lead=None):
         """Initialize the report item collection.
 
         :param workflow: workflow name (e.g. wf-hap-snps)
@@ -295,9 +295,11 @@ class WFReport(HTMLReport):
         self.about = about
         self.style = style
 
-        lead = (
-            "Results generated through the {} Nextflow workflow "
-            "provided by Oxford Nanopore Technologies.".format(workflow))
+        if lead is None:
+            lead = (
+                "Results generated through the {} Nextflow workflow "
+                "provided by Oxford Nanopore Technologies.".format(workflow))
+
         super().__init__(
             title=title, lead=lead, require_keys=require_keys, style=style)
         self.tail_key = str(uuid.uuid4())
@@ -345,7 +347,9 @@ def bokeh_table(df, index=True, **kwargs):
 class Table():
     """A table report component."""
 
-    def __init__(self, data_frame, index, th_color='#0084A9', **kwargs):
+    def __init__(
+            self,
+            data_frame, index, th_color='#0084A9', escape=True, **kwargs):
         """Initialize table component.
 
         :param dataframe: dataframe to turn in to simple table.
@@ -394,5 +398,6 @@ class Table():
         # html id must not begin with numeric
 
         self.div = template.render(
-            dataframe=data_frame.to_html(table_id=key, index=index),
+            dataframe=data_frame.to_html(
+                table_id=key, index=index, escape=escape),
             table_id=key, kwargs=kwargs)
